#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 streaming-commons
version:              0.2.3.1
visibility:           public
id:                   streaming-commons-0.2.3.1-B7SNt6PT5SZBQHQr4Vzf6t
key:                  streaming-commons-0.2.3.1-B7SNt6PT5SZBQHQr4Vzf6t
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman, Emanuel Borsboom
homepage:             https://github.com/fpco/streaming-commons
synopsis:
    Common lower-level functions needed by various streaming data libraries

description:
    Provides low-dependency functionality commonly needed by various streaming data libraries, such as conduit and pipes.

category:             Data
abi:                  aa22a0927f4c8dff7ea6372927b59c74
exposed:              True
exposed-modules:
    Data.Streaming.ByteString.Builder
    Data.Streaming.ByteString.Builder.Buffer Data.Streaming.FileRead
    Data.Streaming.Filesystem Data.Streaming.Network
    Data.Streaming.Network.Internal Data.Streaming.Process
    Data.Streaming.Process.Internal Data.Streaming.Text
    Data.Streaming.Zlib Data.Streaming.Zlib.Lowlevel

import-dirs:          /usr/lib/ghc-9.6.6/site-local/streaming-commons-0.2.3.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/streaming-commons-0.2.3.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/streaming-commons-0.2.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-streaming-commons
hs-libraries:         HSstreaming-commons-0.2.3.1-B7SNt6PT5SZBQHQr4Vzf6t
depends:
    array-0.5.6.0 async-2.2.6-FyNZXdji95t98VleCj3HXu base-4.18.2.1
    bytestring-0.11.5.3 directory-1.3.8.5
    network-3.1.4.0-8HZ2mHT7KyE1ZVQfwLbJCE process-1.6.19.0
    random-1.2.1.3-GfiOoTkiJ8dHrTrBUL8yXz stm-2.5.1.0 text-2.0.2
    transformers-0.6.1.0 unix-2.8.4.0
    zlib-0.7.1.0-9PtbtAjlwdC8Samdliu9GX

haddock-interfaces:
    /usr/share/doc/haskell-streaming-commons/html/streaming-commons.haddock

haddock-html:         /usr/share/doc/haskell-streaming-commons/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

